==> haskell-hspec-hedgehog-0.0.1.2-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-3ADh0MQNGTkF77VFdBmWzr
key:                  hspec-hedgehog-0.0.1.2-3ADh0MQNGTkF77VFdBmWzr
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  6a9ecf2970bce88a6780dd9293458486
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-8.10.3/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hspec-hedgehog-0.0.1.2
hs-libraries:         HShspec-hedgehog-0.0.1.2-3ADh0MQNGTkF77VFdBmWzr
depends:
    HUnit-1.6.1.0-AhWJ4ItV2KqIExS8jxtlOJ
    QuickCheck-2.14.2-7fSQITljDLmG4GADMIuo9 base-4.14.1.0
    hedgehog-1.0.4-JYjiTGYhNTRoQilQoZkus
    hspec-2.7.4-ExhqDPDU3TU7t700iKrDKW
    hspec-core-2.7.4-LGln3vqDDR4CkN74rUmmmS
    splitmix-0.1.0.3-52l6eHRgmGbBav9ABLBRUV

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-hedgehog-0.0.1.2-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-hedgehog
version:              0.0.1.2
visibility:           public
id:                   hspec-hedgehog-0.0.1.2-Ib4OXjWhm4ELs7CAbqVkTC
key:                  hspec-hedgehog-0.0.1.2-Ib4OXjWhm4ELs7CAbqVkTC
license:              BSD-3-Clause
copyright:            2020 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/hspec-hedgehog#readme
synopsis:             Integrate Hedgehog and Hspec!
description:
    Please see the README on GitHub at <https://github.com/parsonsmatt/hspec-hedgehog#readme>

category:             Testing
abi:                  78834b9e7d97d48eabbc1ec2f5f2b577
exposed:              True
exposed-modules:      Test.Hspec.Hedgehog
import-dirs:          /usr/lib/ghc-8.10.3/site-local/hspec-hedgehog-0.0.1.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/hspec-hedgehog-0.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/hspec-hedgehog-0.0.1.2
hs-libraries:         HShspec-hedgehog-0.0.1.2-Ib4OXjWhm4ELs7CAbqVkTC
depends:
    HUnit-1.6.1.0-AhWJ4ItV2KqIExS8jxtlOJ
    QuickCheck-2.14.2-OYA2hlvfC5WNtK6uEYTK base-4.14.1.0
    hedgehog-1.0.4-CRiq8goJh4jEuBEYM8qWQr
    hspec-2.7.4-LNW4VnyjNezHSRaK3MZSbg
    hspec-core-2.7.4-IsXk6P4W2ur74bueebUQLT
    splitmix-0.1.0.3-6Ud8QZxPwl0DIS6Aq14lrm

haddock-interfaces:
    /usr/share/doc/haskell-hspec-hedgehog/html/hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
